@@ -31,6 +31,8 @@
 #include "nvkms.h"
 #include "nv-modeset-interface.h"
 
+#include "nv-retpoline.h"
+
 /*
  * This option decides if nvidia-modeset.ko will be built with support
  * for Linux or Linux 32-bit (FreeBSD/amd64) compatibility.  This
@@ -566,7 +568,11 @@ void NVKMS_API_CALL nvkms_get_random(void *ptr, size_t size)
 
 #if NV_FGET_HAS_CAP_RIGHTS_T_ARG
   #include <sys/caprights.h>
-  #include <sys/capability.h>
+  #if __FreeBSD_version >= 1100012
+    #include <sys/capsicum.h>
+  #else
+    #include <sys/capability.h>
+  #endif
 #endif
 
 /*
